# PyKxnr


## Description

A collection of tools I have developed or adapted for day to day use. What I've covered here is
largely arbitrary, but the basic types of tool are separated out into separate files.

## Setup

### Dependencies

None, though some tools are designed for use with other packages and rely on that package.
If not using those tools, no additional dependencies are needed. Most recently tested on
python 3.7.

### Installation

```
pip install pykxnr
```
  OR
```
python -m pip install pykxnr
```

## Authors

* [Connor Keane](kxnr.me)

## License

This project is licensed under the GPL3 License - see the LICENSE.md file for details

## Acknowledgments

